import { getToken } from '@/utils/auth'
import i18n from '@/i18n'

const state = {
  projectArr: [],   // 项目
  departmentArr: [],    // 部门
  roleArr: [],   // 角色
  pickerOptions: {
    shortcuts: [{
      text: i18n.t('lately_week'), // 最近一周
      onClick(picker) {
        const end = new Date()
        const start = new Date()
        start.setTime(start.getTime() - 3600 * 1000 * 24 * 7)
        picker.$emit('pick', [start, end])
      }
    }, {
      text: i18n.t('lately_one_month'), // 最近一个月
      onClick(picker) {
        const end = new Date()
        const start = new Date()
        start.setTime(start.getTime() - 3600 * 1000 * 24 * 30)
        picker.$emit('pick', [start, end])
      }
    }, {
      text: i18n.t('lately_three_month'), // 最近三个月
      onClick(picker) {
        const end = new Date()
        const start = new Date()
        start.setTime(start.getTime() - 3600 * 1000 * 24 * 90)
        picker.$emit('pick', [start, end])
      }
    }]
  }
}

const mutations = {
  SET_PROJECTARR: (state, arr) => {
    state.projectArr = arr
  },
  SET_DEPARTMENTARR: (state, arr) => {
    state.departmentArr = arr
  },
  SET_ROLEARR: (state, arr) => {
    state.roleArr = arr
  }
}

const actions = {
  async setProjectArr({ commit }) {
    if (!getToken()) return
    const data = await fetch('/api/auth/project/get_list', {}, 'get')
    if (data.code === 200) {
      commit('SET_PROJECTARR', data.data)
    }
  },
  async setDepartmentArr({ commit }) {
    const data = await fetch('/api/auth/department/get_department_list', {}, 'get')
    if (data.code === 200) {
      commit('SET_DEPARTMENTARR', data.data)
    }
  },
  async setRoleArr({ commit }) {
    const data = await fetch('/api/auth/role/get_role_list', {}, 'get')
    if (data.code === 200) {
      commit('SET_ROLEARR', data.data)
    }
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
